@@ -1,7 +1,7 @@
 /* This file is part of TCD 2.0.
    cddb.h - Header file for CDDB routines.
 
-   Copyright (C) 1997-98 Tim P. Gerla <timg@means.net>
+   Copyright (C) 1997-98 Tim P. Gerla <timg@rrv.net>
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,47 +20,21 @@
    Tim P. Gerla
    RR 1, Box 40
    Climax, MN  56523
-   timg@means.net
+   timg@rrv.net
 */
 
 
 #ifndef TCD_CDDB_H
 #define TCD_CDDB_H
 
-#define HOSTNAME_MAX	50
-#define VERSION_MAX	10
-#define CATEG_MAX	20	
-#define DISCID_MAX	10
-#define DTITLE_MAX	80
+#include "linux-cdrom.h"
 
-typedef struct {
-	char hostname[HOSTNAME_MAX];
-	int port;
-	int socket;
-	int connected;
-	char error[100];
-} cddb_server;
-
-typedef struct {
-	int code;
-	char categ[CATEG_MAX];
-	char discid[DISCID_MAX];
-	char dtitle[DTITLE_MAX];
-} cddb_query_str;
-	
-
-int 		tcd_readcddb( cd_struct* cd, char* filename );
-int 		tcd_writecddb( cd_struct* cd, char *filename );
+int 		tcd_readcddb(cd_struct* cd, const char *filename);
+int 		tcd_writecddb(cd_struct* cd, const char *filename);
 int 		cddb_sum(int n);
 unsigned long 	cddb_discid( cd_struct *cd );
-int 		tcd_sendhandshake(  cddb_server *server,
-                		        char* username,
-                			char* hostname,
-                		        char* clientname,
-                		        char* version );
-int 		tcd_getquery( cddb_server *server, cddb_query_str *query );
-void 		tcd_formatquery( cd_struct *cd, char *buf, int blen );
-int 		tcd_open_cddb( cddb_server *server );
-
+void tcd_call_cddb_slave(cd_struct *cd, const char *package, const char *version);
+void tcd_call_cddb_submit(cd_struct *cd, const char *category, const char *service);
+int calc_offset(int minute, int second, int frame);
 
 #endif /* TCD_CDDB_H */
